@@ -33,18 +33,19 @@ class DBConnect:
 
     def write_one_docu(self, docu: dict) -> str:
         try:
+            deep_docu = copy.deepcopy(docu)  # 深拷贝
             # 兼容直接指定ID的创建方式
-            docu = handle_db_id(docu)
+            deep_docu = handle_db_id(deep_docu)
             # 添加创建时间和更新时间，日期格式
-            if not docu.__contains__('creation_time'):
-                docu['creation_time'] = datetime.today()
-            if not docu.__contains__('update_time'):
-                docu['update_time'] = datetime.today()
-            new_data = self.mongo_collection.insert_one(docu)
+            if not deep_docu.__contains__('creation_time'):
+                deep_docu['creation_time'] = datetime.today()
+            if not deep_docu.__contains__('update_time'):
+                deep_docu['update_time'] = datetime.today()
+            new_data = self.mongo_collection.insert_one(deep_docu)
             return str(new_data.inserted_id)
         except Exception as err:
             handle_abnormal(
-                message='MongoDB(组件)出现写入错误: {0}'.format(json.dumps(docu)),
+                message='MongoDB(组件)出现写入错误: {0}'.format(json.dumps(deep_docu)),
                 status=500,
                 other={'prompt': str(err)}
             )
